/********************************************************************************
** Form generated from reading UI file 'opendialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENDIALOG_H
#define UI_OPENDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpenDialog
{
public:
    QVBoxLayout *virticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLabel *label;
    QLabel *label_4;
    QCheckBox *mergeCheckBox;
    QPushButton *fileSelectC;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *swapCopy;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_3;
    QComboBox *lineA;
    QComboBox *lineC;
    QComboBox *lineB;
    QPushButton *fileSelectB;
    QPushButton *folderSelectB;
    QPushButton *folderSelectC;
    QPushButton *folderSelectA;
    QPushButton *fileSelectA;
    QPushButton *selectOutputFile;
    QComboBox *lineOut;
    QPushButton *selectOutputFolder;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OpenDialog)
    {
        if (OpenDialog->objectName().isEmpty())
            OpenDialog->setObjectName("OpenDialog");
        OpenDialog->resize(655, 262);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OpenDialog->sizePolicy().hasHeightForWidth());
        OpenDialog->setSizePolicy(sizePolicy);
        virticalLayout = new QVBoxLayout(OpenDialog);
        virticalLayout->setObjectName("virticalLayout");
        virticalLayout->setContentsMargins(5, 5, 5, 5);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, -1, -1, -1);
        label_2 = new QLabel(OpenDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        label = new QLabel(OpenDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_4 = new QLabel(OpenDialog);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 6, 0, 1, 1);

        mergeCheckBox = new QCheckBox(OpenDialog);
        mergeCheckBox->setObjectName("mergeCheckBox");

        gridLayout->addWidget(mergeCheckBox, 4, 0, 1, 1);

        fileSelectC = new QPushButton(OpenDialog);
        fileSelectC->setObjectName("fileSelectC");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("document-new");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        fileSelectC->setIcon(icon);

        gridLayout->addWidget(fileSelectC, 2, 2, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        swapCopy = new QPushButton(OpenDialog);
        swapCopy->setObjectName("swapCopy");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(swapCopy->sizePolicy().hasHeightForWidth());
        swapCopy->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(swapCopy);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_2, 4, 1, 1, 1);

        label_3 = new QLabel(OpenDialog);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        lineA = new QComboBox(OpenDialog);
        lineA->setObjectName("lineA");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(10);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lineA->sizePolicy().hasHeightForWidth());
        lineA->setSizePolicy(sizePolicy2);
        lineA->setMinimumSize(QSize(200, 0));
        lineA->setAcceptDrops(true);
        lineA->setEditable(true);

        gridLayout->addWidget(lineA, 0, 1, 1, 1);

        lineC = new QComboBox(OpenDialog);
        lineC->setObjectName("lineC");
        sizePolicy2.setHeightForWidth(lineC->sizePolicy().hasHeightForWidth());
        lineC->setSizePolicy(sizePolicy2);
        lineC->setMinimumSize(QSize(200, 0));
        lineC->setAcceptDrops(true);
        lineC->setEditable(true);

        gridLayout->addWidget(lineC, 2, 1, 1, 1);

        lineB = new QComboBox(OpenDialog);
        lineB->setObjectName("lineB");
        sizePolicy2.setHeightForWidth(lineB->sizePolicy().hasHeightForWidth());
        lineB->setSizePolicy(sizePolicy2);
        lineB->setMinimumSize(QSize(200, 0));
        lineB->setAcceptDrops(true);
        lineB->setEditable(true);

        gridLayout->addWidget(lineB, 1, 1, 1, 1);

        fileSelectB = new QPushButton(OpenDialog);
        fileSelectB->setObjectName("fileSelectB");
        fileSelectB->setIcon(icon);

        gridLayout->addWidget(fileSelectB, 1, 2, 1, 1);

        folderSelectB = new QPushButton(OpenDialog);
        folderSelectB->setObjectName("folderSelectB");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("document-open-folder");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        folderSelectB->setIcon(icon1);

        gridLayout->addWidget(folderSelectB, 1, 3, 1, 1);

        folderSelectC = new QPushButton(OpenDialog);
        folderSelectC->setObjectName("folderSelectC");
        folderSelectC->setIcon(icon1);

        gridLayout->addWidget(folderSelectC, 2, 3, 1, 1);

        folderSelectA = new QPushButton(OpenDialog);
        folderSelectA->setObjectName("folderSelectA");
        folderSelectA->setIcon(icon1);

        gridLayout->addWidget(folderSelectA, 0, 3, 1, 1);

        fileSelectA = new QPushButton(OpenDialog);
        fileSelectA->setObjectName("fileSelectA");
        fileSelectA->setIcon(icon);

        gridLayout->addWidget(fileSelectA, 0, 2, 1, 1);

        selectOutputFile = new QPushButton(OpenDialog);
        selectOutputFile->setObjectName("selectOutputFile");
        selectOutputFile->setIcon(icon);

        gridLayout->addWidget(selectOutputFile, 6, 2, 1, 1);

        lineOut = new QComboBox(OpenDialog);
        lineOut->setObjectName("lineOut");
        sizePolicy2.setHeightForWidth(lineOut->sizePolicy().hasHeightForWidth());
        lineOut->setSizePolicy(sizePolicy2);
        lineOut->setMinimumSize(QSize(200, 0));
        lineOut->setAcceptDrops(true);
        lineOut->setEditable(true);

        gridLayout->addWidget(lineOut, 6, 1, 1, 1);

        selectOutputFolder = new QPushButton(OpenDialog);
        selectOutputFolder->setObjectName("selectOutputFolder");
        selectOutputFolder->setIcon(icon1);

        gridLayout->addWidget(selectOutputFolder, 6, 3, 1, 1);


        virticalLayout->addLayout(gridLayout);

        buttonBox = new QDialogButtonBox(OpenDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        virticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(lineA, fileSelectA);
        QWidget::setTabOrder(fileSelectA, folderSelectA);
        QWidget::setTabOrder(folderSelectA, lineB);
        QWidget::setTabOrder(lineB, fileSelectB);
        QWidget::setTabOrder(fileSelectB, folderSelectB);
        QWidget::setTabOrder(folderSelectB, lineC);
        QWidget::setTabOrder(lineC, fileSelectC);
        QWidget::setTabOrder(fileSelectC, folderSelectC);
        QWidget::setTabOrder(folderSelectC, mergeCheckBox);
        QWidget::setTabOrder(mergeCheckBox, swapCopy);
        QWidget::setTabOrder(swapCopy, lineOut);
        QWidget::setTabOrder(lineOut, selectOutputFile);
        QWidget::setTabOrder(selectOutputFile, selectOutputFolder);

        retranslateUi(OpenDialog);

        QMetaObject::connectSlotsByName(OpenDialog);
    } // setupUi

    void retranslateUi(QDialog *OpenDialog)
    {
        OpenDialog->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_2->setText(tr2i18n("B:", nullptr));
        label->setText(tr2i18n("A (Base):", nullptr));
        label_4->setText(tr2i18n("Output (Optional):", nullptr));
        mergeCheckBox->setText(tr2i18n("Merge", nullptr));
        fileSelectC->setText(tr2i18n("File...", nullptr));
        swapCopy->setText(tr2i18n("Swap/Copy Names...", nullptr));
        label_3->setText(tr2i18n("C (Optional):", nullptr));
        fileSelectB->setText(tr2i18n("File...", nullptr));
        folderSelectB->setText(tr2i18n("Folder...", nullptr));
        folderSelectC->setText(tr2i18n("Folder...", nullptr));
        folderSelectA->setText(tr2i18n("Folder...", nullptr));
        fileSelectA->setText(tr2i18n("File...", nullptr));
        selectOutputFile->setText(tr2i18n("File...", nullptr));
        selectOutputFolder->setText(tr2i18n("Folder...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenDialog: public Ui_OpenDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENDIALOG_H

