/********************************************************************************
** Form generated from reading UI file 'scroller.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCROLLER_H
#define UI_SCROLLER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScrollArea
{
public:
    QWidget *contents;

    void setupUi(QScrollArea *ScrollArea)
    {
        if (ScrollArea->objectName().isEmpty())
            ScrollArea->setObjectName("ScrollArea");
        ScrollArea->resize(525, 432);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ScrollArea->sizePolicy().hasHeightForWidth());
        ScrollArea->setSizePolicy(sizePolicy);
        ScrollArea->setLayoutDirection(Qt::LeftToRight);
        ScrollArea->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        ScrollArea->setWidgetResizable(true);
        contents = new QWidget();
        contents->setObjectName("contents");
        contents->setGeometry(QRect(0, 0, 521, 428));
        ScrollArea->setWidget(contents);

        retranslateUi(ScrollArea);

        QMetaObject::connectSlotsByName(ScrollArea);
    } // setupUi

    void retranslateUi(QScrollArea *ScrollArea)
    {
        (void)ScrollArea;
    } // retranslateUi

};

namespace Ui {
    class ScrollArea: public Ui_ScrollArea {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCROLLER_H

