/****************************************************************************
** Meta object code from reading C++ file 'mergeresultwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdiff3-1.12.5/src/mergeresultwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mergeresultwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17MergeResultWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MergeResultWindow::qt_create_metaobjectdata<qt_meta_tag_ZN17MergeResultWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MergeResultWindow",
        "statusBarMessage",
        "",
        "message",
        "scrollMergeResultWindow",
        "deltaX",
        "deltaY",
        "modifiedChanged",
        "bModified",
        "setFastSelectorRange",
        "LineRef",
        "line1",
        "LineType",
        "nofLines",
        "sourceMask",
        "srcMask",
        "enabledMask",
        "resizeSignal",
        "selectionEnd",
        "newSelection",
        "updateAvailabilities",
        "showPopupMenu",
        "QPoint",
        "point",
        "noRelevantChangesDetected",
        "scrollToH",
        "qsizetype",
        "pos",
        "setOverviewMode",
        "e_OverviewMode",
        "eOverviewMode",
        "setFirstLine",
        "firstLine",
        "setHorizScrollOffset",
        "horizScrollOffset",
        "slotGoCurrent",
        "slotGoTop",
        "slotGoBottom",
        "slotGoPrevDelta",
        "slotGoNextDelta",
        "slotGoPrevUnsolvedConflict",
        "slotGoNextUnsolvedConflict",
        "slotGoPrevConflict",
        "slotGoNextConflict",
        "slotAutoSolve",
        "slotUnsolve",
        "slotMergeHistory",
        "slotRegExpAutoMerge",
        "slotSplitDiff",
        "firstD3lLineIdx",
        "lastD3lLineIdx",
        "slotJoinDiffs",
        "slotSetFastSelectorLine",
        "setPaintingAllowed",
        "updateSourceMask",
        "slotStatusMessageChanged",
        "slotChooseAEverywhere",
        "slotChooseBEverywhere",
        "slotChooseCEverywhere",
        "slotChooseAForUnsolvedConflicts",
        "slotChooseBForUnsolvedConflicts",
        "slotChooseCForUnsolvedConflicts",
        "slotChooseAForUnsolvedWhiteSpaceConflicts",
        "slotChooseBForUnsolvedWhiteSpaceConflicts",
        "slotChooseCForUnsolvedWhiteSpaceConflicts",
        "slotRefresh",
        "slotResize",
        "slotCut",
        "slotCopy",
        "slotSelectAll",
        "scrollVertically",
        "deleteSelection",
        "pasteClipboard",
        "bFromSelection",
        "slotCursorUpdate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusBarMessage'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'scrollMergeResultWindow'
        QtMocHelpers::SignalData<void(qint32, qint32)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'setFastSelectorRange'
        QtMocHelpers::SignalData<void(LineRef, LineType)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'sourceMask'
        QtMocHelpers::SignalData<void(qint32, qint32)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'resizeSignal'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionEnd'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newSelection'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateAvailabilities'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showPopupMenu'
        QtMocHelpers::SignalData<void(const QPoint &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'noRelevantChangesDetected'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollToH'
        QtMocHelpers::SignalData<void(qsizetype)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'setOverviewMode'
        QtMocHelpers::SlotData<void(e_OverviewMode)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'setFirstLine'
        QtMocHelpers::SlotData<void(LineRef)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 32 },
        }}),
        // Slot 'setHorizScrollOffset'
        QtMocHelpers::SlotData<void(const qint32)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'slotGoCurrent'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoTop'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoBottom'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoPrevDelta'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoNextDelta'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoPrevUnsolvedConflict'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoNextUnsolvedConflict'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoPrevConflict'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoNextConflict'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAutoSolve'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUnsolve'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMergeHistory'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRegExpAutoMerge'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSplitDiff'
        QtMocHelpers::SlotData<void(LineType, LineType)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 49 }, { 0x80000000 | 12, 50 },
        }}),
        // Slot 'slotJoinDiffs'
        QtMocHelpers::SlotData<void(LineType, LineType)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 49 }, { 0x80000000 | 12, 50 },
        }}),
        // Slot 'slotSetFastSelectorLine'
        QtMocHelpers::SlotData<void(LineType)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'setPaintingAllowed'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateSourceMask'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStatusMessageChanged'
        QtMocHelpers::SlotData<void(const QString &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotChooseAEverywhere'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseBEverywhere'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseCEverywhere'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseAForUnsolvedConflicts'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseBForUnsolvedConflicts'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseCForUnsolvedConflicts'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseAForUnsolvedWhiteSpaceConflicts'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseBForUnsolvedWhiteSpaceConflicts'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseCForUnsolvedWhiteSpaceConflicts'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotResize'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCut'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scrollVertically'
        QtMocHelpers::SlotData<void(qint32)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'deleteSelection'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteClipboard'
        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'slotCursorUpdate'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MergeResultWindow, qt_meta_tag_ZN17MergeResultWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MergeResultWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MergeResultWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MergeResultWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17MergeResultWindowE_t>.metaTypes,
    nullptr
} };

void MergeResultWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MergeResultWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusBarMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->scrollMergeResultWindow((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 2: _t->modifiedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setFastSelectorRange((*reinterpret_cast<std::add_pointer_t<LineRef>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LineType>>(_a[2]))); break;
        case 4: _t->sourceMask((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 5: _t->resizeSignal(); break;
        case 6: _t->selectionEnd(); break;
        case 7: _t->newSelection(); break;
        case 8: _t->updateAvailabilities(); break;
        case 9: _t->showPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 10: _t->noRelevantChangesDetected(); break;
        case 11: _t->scrollToH((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1]))); break;
        case 12: _t->setOverviewMode((*reinterpret_cast<std::add_pointer_t<e_OverviewMode>>(_a[1]))); break;
        case 13: _t->setFirstLine((*reinterpret_cast<std::add_pointer_t<LineRef>>(_a[1]))); break;
        case 14: _t->setHorizScrollOffset((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 15: _t->slotGoCurrent(); break;
        case 16: _t->slotGoTop(); break;
        case 17: _t->slotGoBottom(); break;
        case 18: _t->slotGoPrevDelta(); break;
        case 19: _t->slotGoNextDelta(); break;
        case 20: _t->slotGoPrevUnsolvedConflict(); break;
        case 21: _t->slotGoNextUnsolvedConflict(); break;
        case 22: _t->slotGoPrevConflict(); break;
        case 23: _t->slotGoNextConflict(); break;
        case 24: _t->slotAutoSolve(); break;
        case 25: _t->slotUnsolve(); break;
        case 26: _t->slotMergeHistory(); break;
        case 27: _t->slotRegExpAutoMerge(); break;
        case 28: _t->slotSplitDiff((*reinterpret_cast<std::add_pointer_t<LineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LineType>>(_a[2]))); break;
        case 29: _t->slotJoinDiffs((*reinterpret_cast<std::add_pointer_t<LineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LineType>>(_a[2]))); break;
        case 30: _t->slotSetFastSelectorLine((*reinterpret_cast<std::add_pointer_t<LineType>>(_a[1]))); break;
        case 31: _t->setPaintingAllowed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->updateSourceMask(); break;
        case 33: _t->slotStatusMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->slotChooseAEverywhere(); break;
        case 35: _t->slotChooseBEverywhere(); break;
        case 36: _t->slotChooseCEverywhere(); break;
        case 37: _t->slotChooseAForUnsolvedConflicts(); break;
        case 38: _t->slotChooseBForUnsolvedConflicts(); break;
        case 39: _t->slotChooseCForUnsolvedConflicts(); break;
        case 40: _t->slotChooseAForUnsolvedWhiteSpaceConflicts(); break;
        case 41: _t->slotChooseBForUnsolvedWhiteSpaceConflicts(); break;
        case 42: _t->slotChooseCForUnsolvedWhiteSpaceConflicts(); break;
        case 43: _t->slotRefresh(); break;
        case 44: _t->slotResize(); break;
        case 45: _t->slotCut(); break;
        case 46: _t->slotCopy(); break;
        case 47: _t->slotSelectAll(); break;
        case 48: _t->scrollVertically((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 49: _t->deleteSelection(); break;
        case 50: _t->pasteClipboard((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: _t->slotCursorUpdate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)(const QString & )>(_a, &MergeResultWindow::statusBarMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)(qint32 , qint32 )>(_a, &MergeResultWindow::scrollMergeResultWindow, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)(bool )>(_a, &MergeResultWindow::modifiedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)(LineRef , LineType )>(_a, &MergeResultWindow::setFastSelectorRange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)(qint32 , qint32 )>(_a, &MergeResultWindow::sourceMask, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)()>(_a, &MergeResultWindow::resizeSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)()>(_a, &MergeResultWindow::selectionEnd, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)()>(_a, &MergeResultWindow::newSelection, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)()>(_a, &MergeResultWindow::updateAvailabilities, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)(const QPoint & )>(_a, &MergeResultWindow::showPopupMenu, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)()>(_a, &MergeResultWindow::noRelevantChangesDetected, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeResultWindow::*)(qsizetype )>(_a, &MergeResultWindow::scrollToH, 11))
            return;
    }
}

const QMetaObject *MergeResultWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MergeResultWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MergeResultWindowE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MergeResultWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 52)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 52;
    }
    return _id;
}

// SIGNAL 0
void MergeResultWindow::statusBarMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MergeResultWindow::scrollMergeResultWindow(qint32 _t1, qint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void MergeResultWindow::modifiedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MergeResultWindow::setFastSelectorRange(LineRef _t1, LineType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void MergeResultWindow::sourceMask(qint32 _t1, qint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void MergeResultWindow::resizeSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MergeResultWindow::selectionEnd()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MergeResultWindow::newSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MergeResultWindow::updateAvailabilities()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MergeResultWindow::showPopupMenu(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void MergeResultWindow::noRelevantChangesDetected()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MergeResultWindow::scrollToH(qsizetype _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN17WindowTitleWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto WindowTitleWidget::qt_create_metaobjectdata<qt_meta_tag_ZN17WindowTitleWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WindowTitleWidget",
        "slotSetModified",
        "",
        "bModified"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotSetModified'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WindowTitleWidget, qt_meta_tag_ZN17WindowTitleWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WindowTitleWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WindowTitleWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WindowTitleWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17WindowTitleWidgetE_t>.metaTypes,
    nullptr
} };

void WindowTitleWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WindowTitleWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotSetModified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *WindowTitleWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WindowTitleWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WindowTitleWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int WindowTitleWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
