/****************************************************************************
** Meta object code from reading C++ file 'kdiff3.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdiff3-1.12.5/src/kdiff3.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdiff3.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19ReversibleScrollBarE_t {};
} // unnamed namespace

template <> constexpr inline auto ReversibleScrollBar::qt_create_metaobjectdata<qt_meta_tag_ZN19ReversibleScrollBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReversibleScrollBar",
        "valueChanged2",
        "",
        "slotValueChanged",
        "i"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'valueChanged2'
        QtMocHelpers::SignalData<void(qint32)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotValueChanged'
        QtMocHelpers::SlotData<void(qint32)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReversibleScrollBar, qt_meta_tag_ZN19ReversibleScrollBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReversibleScrollBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ReversibleScrollBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ReversibleScrollBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19ReversibleScrollBarE_t>.metaTypes,
    nullptr
} };

void ReversibleScrollBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReversibleScrollBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->valueChanged2((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 1: _t->slotValueChanged((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReversibleScrollBar::*)(qint32 )>(_a, &ReversibleScrollBar::valueChanged2, 0))
            return;
    }
}

const QMetaObject *ReversibleScrollBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReversibleScrollBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ReversibleScrollBarE_t>.strings))
        return static_cast<void*>(this);
    return QScrollBar::qt_metacast(_clname);
}

int ReversibleScrollBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ReversibleScrollBar::valueChanged2(qint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN9KDiff3AppE_t {};
} // unnamed namespace

template <> constexpr inline auto KDiff3App::qt_create_metaobjectdata<qt_meta_tag_ZN9KDiff3AppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDiff3App",
        "createNewInstance",
        "",
        "fn1",
        "fn2",
        "fn3",
        "sigRecalcWordWrap",
        "finishDrop",
        "showWhiteSpaceToggled",
        "showLineNumbersToggled",
        "doRefresh",
        "autoSolve",
        "unsolve",
        "mergeHistory",
        "regExpAutoMerge",
        "goCurrent",
        "goTop",
        "goBottom",
        "goPrevUnsolvedConflict",
        "goNextUnsolvedConflict",
        "goPrevConflict",
        "goNextConflict",
        "goPrevDelta",
        "goNextDelta",
        "cut",
        "copy",
        "selectAll",
        "changeOverViewMode",
        "e_OverviewMode",
        "updateAvailabilities",
        "slotFileOpen",
        "slotFileOpen2",
        "QStringList&",
        "errors",
        "ofn",
        "an1",
        "an2",
        "an3",
        "TotalDiffStatus*",
        "pTotalDiffStatus",
        "slotFileNameChanged",
        "fileName",
        "e_SrcSelector",
        "winIdx",
        "slotFileSave",
        "slotFileSaveAs",
        "slotFilePrint",
        "slotFileQuit",
        "slotEditUndo",
        "slotEditCut",
        "slotEditCopy",
        "slotEditPaste",
        "slotViewStatusBar",
        "slotStatusMsg",
        "text",
        "resizeDiffTextWindowHeight",
        "LineType",
        "newHeight",
        "slotRecalcWordWrap",
        "postRecalcWordWrap",
        "slotFinishRecalcWordWrap",
        "visibleTextWidth",
        "showPopupMenu",
        "QPoint",
        "point",
        "scrollDiffTextWindow",
        "deltaX",
        "deltaY",
        "scrollMergeResultWindow",
        "sourceMask",
        "srcMask",
        "enabledMask",
        "slotDirShowBoth",
        "slotDirViewToggle",
        "slotUpdateAvailabilities",
        "slotEditSelectAll",
        "slotEditFind",
        "slotEditFindNext",
        "slotGoNextUnsolvedConflict",
        "slotGoNextConflict",
        "slotGoToLine",
        "slotAutoSolve",
        "slotConfigure",
        "slotConfigureKeys",
        "slotRefresh",
        "slotSelectionEnd",
        "slotSelectionStart",
        "slotOutputModified",
        "slotFinishMainInit",
        "slotMergeCurrentFile",
        "slotReload",
        "slotShowWhiteSpaceToggled",
        "slotShowLineNumbersToggled",
        "slotAutoAdvanceToggled",
        "slotWordWrapToggled",
        "slotShowWindowAToggled",
        "slotShowWindowBToggled",
        "slotShowWindowCToggled",
        "slotWinFocusNext",
        "slotWinFocusPrev",
        "slotWinToggleSplitterOrientation",
        "slotOverviewNormal",
        "slotOverviewAB",
        "slotOverviewAC",
        "slotOverviewBC",
        "slotSplitDiff",
        "slotJoinDiffs",
        "slotAddManualDiffHelp",
        "slotClearManualDiffHelpList",
        "slotNoRelevantChangesDetected",
        "slotEncodingChanged",
        "slotFinishDrop",
        "setHScrollBarRange",
        "slotFocusChanged",
        "QWidget*",
        "old",
        "now",
        "slotScrollToH",
        "qsizetype",
        "p"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'createNewInstance'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'sigRecalcWordWrap'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finishDrop'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showWhiteSpaceToggled'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showLineNumbersToggled'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doRefresh'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoSolve'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unsolve'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mergeHistory'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'regExpAutoMerge'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goCurrent'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goTop'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goBottom'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goPrevUnsolvedConflict'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goNextUnsolvedConflict'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goPrevConflict'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goNextConflict'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goPrevDelta'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goNextDelta'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cut'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copy'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAll'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changeOverViewMode'
        QtMocHelpers::SignalData<void(e_OverviewMode)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Signal 'updateAvailabilities'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileOpen'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileOpen2'
        QtMocHelpers::SlotData<void(QStringList &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, TotalDiffStatus *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
            { QMetaType::QString, 34 }, { QMetaType::QString, 35 }, { QMetaType::QString, 36 }, { QMetaType::QString, 37 },
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'slotFileNameChanged'
        QtMocHelpers::SlotData<void(const QString &, e_SrcSelector)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { 0x80000000 | 42, 43 },
        }}),
        // Slot 'slotFileSave'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileSaveAs'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFilePrint'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileQuit'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditUndo'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditCut'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditCopy'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditPaste'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotViewStatusBar'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStatusMsg'
        QtMocHelpers::SlotData<void(const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 54 },
        }}),
        // Slot 'resizeDiffTextWindowHeight'
        QtMocHelpers::SlotData<void(LineType)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'slotRecalcWordWrap'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'postRecalcWordWrap'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFinishRecalcWordWrap'
        QtMocHelpers::SlotData<void(qint32)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Slot 'showPopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'scrollDiffTextWindow'
        QtMocHelpers::SlotData<void(qint32, qint32)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 66 }, { QMetaType::Int, 67 },
        }}),
        // Slot 'scrollMergeResultWindow'
        QtMocHelpers::SlotData<void(qint32, qint32)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 66 }, { QMetaType::Int, 67 },
        }}),
        // Slot 'sourceMask'
        QtMocHelpers::SlotData<void(qint32, qint32)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 70 }, { QMetaType::Int, 71 },
        }}),
        // Slot 'slotDirShowBoth'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDirViewToggle'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateAvailabilities'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditSelectAll'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditFind'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditFindNext'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoNextUnsolvedConflict'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoNextConflict'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoToLine'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAutoSolve'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigure'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigureKeys'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectionEnd'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectionStart'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOutputModified'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotFinishMainInit'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMergeCurrentFile'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReload'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowWhiteSpaceToggled'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowLineNumbersToggled'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAutoAdvanceToggled'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWordWrapToggled'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowWindowAToggled'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowWindowBToggled'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowWindowCToggled'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWinFocusNext'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWinFocusPrev'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWinToggleSplitterOrientation'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOverviewNormal'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOverviewAB'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOverviewAC'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOverviewBC'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSplitDiff'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotJoinDiffs'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddManualDiffHelp'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClearManualDiffHelpList'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNoRelevantChangesDetected'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEncodingChanged'
        QtMocHelpers::SlotData<void(const QByteArray &)>(110, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 },
        }}),
        // Slot 'slotFinishDrop'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setHScrollBarRange'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFocusChanged'
        QtMocHelpers::SlotData<void(QWidget *, QWidget *)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 114, 115 }, { 0x80000000 | 114, 116 },
        }}),
        // Slot 'slotScrollToH'
        QtMocHelpers::SlotData<void(qsizetype)>(117, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 118, 119 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KDiff3App, qt_meta_tag_ZN9KDiff3AppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDiff3App::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KDiff3AppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KDiff3AppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KDiff3AppE_t>.metaTypes,
    nullptr
} };

void KDiff3App::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KDiff3App *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createNewInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->sigRecalcWordWrap(); break;
        case 2: _t->finishDrop(); break;
        case 3: _t->showWhiteSpaceToggled(); break;
        case 4: _t->showLineNumbersToggled(); break;
        case 5: _t->doRefresh(); break;
        case 6: _t->autoSolve(); break;
        case 7: _t->unsolve(); break;
        case 8: _t->mergeHistory(); break;
        case 9: _t->regExpAutoMerge(); break;
        case 10: _t->goCurrent(); break;
        case 11: _t->goTop(); break;
        case 12: _t->goBottom(); break;
        case 13: _t->goPrevUnsolvedConflict(); break;
        case 14: _t->goNextUnsolvedConflict(); break;
        case 15: _t->goPrevConflict(); break;
        case 16: _t->goNextConflict(); break;
        case 17: _t->goPrevDelta(); break;
        case 18: _t->goNextDelta(); break;
        case 19: _t->cut(); break;
        case 20: _t->copy(); break;
        case 21: _t->selectAll(); break;
        case 22: _t->changeOverViewMode((*reinterpret_cast<std::add_pointer_t<e_OverviewMode>>(_a[1]))); break;
        case 23: _t->updateAvailabilities(); break;
        case 24: _t->slotFileOpen(); break;
        case 25: _t->slotFileOpen2((*reinterpret_cast<std::add_pointer_t<QStringList&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<TotalDiffStatus*>>(_a[9]))); break;
        case 26: _t->slotFileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<e_SrcSelector>>(_a[2]))); break;
        case 27: _t->slotFileSave(); break;
        case 28: _t->slotFileSaveAs(); break;
        case 29: _t->slotFilePrint(); break;
        case 30: _t->slotFileQuit(); break;
        case 31: _t->slotEditUndo(); break;
        case 32: _t->slotEditCut(); break;
        case 33: _t->slotEditCopy(); break;
        case 34: _t->slotEditPaste(); break;
        case 35: _t->slotViewStatusBar(); break;
        case 36: _t->slotStatusMsg((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->resizeDiffTextWindowHeight((*reinterpret_cast<std::add_pointer_t<LineType>>(_a[1]))); break;
        case 38: _t->slotRecalcWordWrap(); break;
        case 39: _t->postRecalcWordWrap(); break;
        case 40: _t->slotFinishRecalcWordWrap((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 41: _t->showPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 42: _t->scrollDiffTextWindow((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 43: _t->scrollMergeResultWindow((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 44: _t->sourceMask((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 45: _t->slotDirShowBoth(); break;
        case 46: _t->slotDirViewToggle(); break;
        case 47: _t->slotUpdateAvailabilities(); break;
        case 48: _t->slotEditSelectAll(); break;
        case 49: _t->slotEditFind(); break;
        case 50: _t->slotEditFindNext(); break;
        case 51: _t->slotGoNextUnsolvedConflict(); break;
        case 52: _t->slotGoNextConflict(); break;
        case 53: _t->slotGoToLine(); break;
        case 54: _t->slotAutoSolve(); break;
        case 55: _t->slotConfigure(); break;
        case 56: _t->slotConfigureKeys(); break;
        case 57: _t->slotRefresh(); break;
        case 58: _t->slotSelectionEnd(); break;
        case 59: _t->slotSelectionStart(); break;
        case 60: _t->slotOutputModified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->slotFinishMainInit(); break;
        case 62: _t->slotMergeCurrentFile(); break;
        case 63: _t->slotReload(); break;
        case 64: _t->slotShowWhiteSpaceToggled(); break;
        case 65: _t->slotShowLineNumbersToggled(); break;
        case 66: _t->slotAutoAdvanceToggled(); break;
        case 67: _t->slotWordWrapToggled(); break;
        case 68: _t->slotShowWindowAToggled(); break;
        case 69: _t->slotShowWindowBToggled(); break;
        case 70: _t->slotShowWindowCToggled(); break;
        case 71: _t->slotWinFocusNext(); break;
        case 72: _t->slotWinFocusPrev(); break;
        case 73: _t->slotWinToggleSplitterOrientation(); break;
        case 74: _t->slotOverviewNormal(); break;
        case 75: _t->slotOverviewAB(); break;
        case 76: _t->slotOverviewAC(); break;
        case 77: _t->slotOverviewBC(); break;
        case 78: _t->slotSplitDiff(); break;
        case 79: _t->slotJoinDiffs(); break;
        case 80: _t->slotAddManualDiffHelp(); break;
        case 81: _t->slotClearManualDiffHelpList(); break;
        case 82: _t->slotNoRelevantChangesDetected(); break;
        case 83: _t->slotEncodingChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 84: _t->slotFinishDrop(); break;
        case 85: _t->setHScrollBarRange(); break;
        case 86: _t->slotFocusChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 87: _t->slotScrollToH((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 86:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)(const QString & , const QString & , const QString & )>(_a, &KDiff3App::createNewInstance, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::sigRecalcWordWrap, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::finishDrop, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::showWhiteSpaceToggled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::showLineNumbersToggled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::doRefresh, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::autoSolve, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::unsolve, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::mergeHistory, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::regExpAutoMerge, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goCurrent, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goTop, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goBottom, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goPrevUnsolvedConflict, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goNextUnsolvedConflict, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goPrevConflict, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goNextConflict, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goPrevDelta, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::goNextDelta, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::cut, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::copy, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::selectAll, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)(e_OverviewMode )>(_a, &KDiff3App::changeOverViewMode, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDiff3App::*)()>(_a, &KDiff3App::updateAvailabilities, 23))
            return;
    }
}

const QMetaObject *KDiff3App::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDiff3App::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KDiff3AppE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int KDiff3App::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 88)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 88;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 88)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 88;
    }
    return _id;
}

// SIGNAL 0
void KDiff3App::createNewInstance(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void KDiff3App::sigRecalcWordWrap()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDiff3App::finishDrop()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KDiff3App::showWhiteSpaceToggled()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KDiff3App::showLineNumbersToggled()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KDiff3App::doRefresh()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KDiff3App::autoSolve()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KDiff3App::unsolve()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KDiff3App::mergeHistory()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KDiff3App::regExpAutoMerge()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KDiff3App::goCurrent()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KDiff3App::goTop()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KDiff3App::goBottom()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KDiff3App::goPrevUnsolvedConflict()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KDiff3App::goNextUnsolvedConflict()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KDiff3App::goPrevConflict()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KDiff3App::goNextConflict()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KDiff3App::goPrevDelta()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KDiff3App::goNextDelta()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KDiff3App::cut()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KDiff3App::copy()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KDiff3App::selectAll()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KDiff3App::changeOverViewMode(e_OverviewMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void KDiff3App::updateAvailabilities()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}
QT_WARNING_POP
