/********************************************************************************
** Form generated from reading UI file 'FontChooser.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTCHOOSER_H
#define UI_FONTCHOOSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FontGroupBox
{
public:
    QVBoxLayout *layout;
    QLabel *label;
    QPlainTextEdit *exampleTextEdit;
    QPushButton *selectFont;

    void setupUi(QGroupBox *FontGroupBox)
    {
        if (FontGroupBox->objectName().isEmpty())
            FontGroupBox->setObjectName("FontGroupBox");
        FontGroupBox->resize(760, 615);
        layout = new QVBoxLayout(FontGroupBox);
        layout->setObjectName("layout");
        label = new QLabel(FontGroupBox);
        label->setObjectName("label");

        layout->addWidget(label);

        exampleTextEdit = new QPlainTextEdit(FontGroupBox);
        exampleTextEdit->setObjectName("exampleTextEdit");
        exampleTextEdit->setReadOnly(true);

        layout->addWidget(exampleTextEdit);

        selectFont = new QPushButton(FontGroupBox);
        selectFont->setObjectName("selectFont");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(selectFont->sizePolicy().hasHeightForWidth());
        selectFont->setSizePolicy(sizePolicy);

        layout->addWidget(selectFont, 0, Qt::AlignRight);


        retranslateUi(FontGroupBox);

        QMetaObject::connectSlotsByName(FontGroupBox);
    } // setupUi

    void retranslateUi(QGroupBox *FontGroupBox)
    {
        label->setText(tr2i18n("TextLabel", nullptr));
        exampleTextEdit->setPlainText(tr2i18n("The quick brown fox jumps over the river\n"
"but the little red hen escapes with a shiver\n"
":-)\n"
"", nullptr));
        selectFont->setText(tr2i18n("Change Font", "Button Title"));
        (void)FontGroupBox;
    } // retranslateUi

};

namespace Ui {
    class FontGroupBox: public Ui_FontGroupBox {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FONTCHOOSER_H

