/****************************************************************************
** Meta object code from reading C++ file 'difftextwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdiff3-1.12.5/src/difftextwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'difftextwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14DiffTextWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto DiffTextWindow::qt_create_metaobjectdata<qt_meta_tag_ZN14DiffTextWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiffTextWindow",
        "statusBarMessage",
        "",
        "message",
        "resizeHeightChangedSignal",
        "LineType",
        "nofVisibleLines",
        "resizeWidthChangedSignal",
        "nofVisibleColumns",
        "scrollDiffTextWindow",
        "deltaX",
        "deltaY",
        "newSelection",
        "selectionEnd",
        "setFastSelectorLine",
        "line",
        "gotFocus",
        "lineClicked",
        "e_SrcSelector",
        "winIdx",
        "LineRef",
        "finishRecalcWordWrap",
        "visibleTextWidthForPrinting",
        "finishDrop",
        "firstLineChanged",
        "firstLine",
        "scrollToH",
        "qsizetype",
        "pos",
        "setFirstLine",
        "setHorizScrollOffset",
        "horizScrollOffset",
        "resetSelection",
        "setFastSelectorRange",
        "line1",
        "nofLines",
        "slotRefresh",
        "slotSelectAll",
        "slotCopy",
        "fwdFinishRecalcWordWrap",
        "recalcWordWrapHelper",
        "size_t",
        "wrapLineVectorSize",
        "visibleTextWidth",
        "cacheListIdx"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusBarMessage'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'resizeHeightChangedSignal'
        QtMocHelpers::SignalData<void(LineType)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'resizeWidthChangedSignal'
        QtMocHelpers::SignalData<void(qint32)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'scrollDiffTextWindow'
        QtMocHelpers::SignalData<void(qint32, qint32)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'newSelection'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionEnd'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setFastSelectorLine'
        QtMocHelpers::SignalData<void(LineType)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 15 },
        }}),
        // Signal 'gotFocus'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineClicked'
        QtMocHelpers::SignalData<void(e_SrcSelector, LineRef)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 15 },
        }}),
        // Signal 'finishRecalcWordWrap'
        QtMocHelpers::SignalData<void(qint32)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Signal 'finishDrop'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firstLineChanged'
        QtMocHelpers::SignalData<void(const LineRef)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 25 },
        }}),
        // Signal 'scrollToH'
        QtMocHelpers::SignalData<void(qsizetype)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'setFirstLine'
        QtMocHelpers::SlotData<void(LineRef)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 15 },
        }}),
        // Slot 'setHorizScrollOffset'
        QtMocHelpers::SlotData<void(qint32)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'resetSelection'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFastSelectorRange'
        QtMocHelpers::SlotData<void(qint32, qint32)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 35 },
        }}),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fwdFinishRecalcWordWrap'
        QtMocHelpers::SlotData<void(qint32)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'recalcWordWrapHelper'
        QtMocHelpers::SlotData<void(size_t, qint32, size_t)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 }, { QMetaType::Int, 43 }, { 0x80000000 | 41, 44 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DiffTextWindow, qt_meta_tag_ZN14DiffTextWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DiffTextWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DiffTextWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DiffTextWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14DiffTextWindowE_t>.metaTypes,
    nullptr
} };

void DiffTextWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiffTextWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusBarMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->resizeHeightChangedSignal((*reinterpret_cast<std::add_pointer_t<LineType>>(_a[1]))); break;
        case 2: _t->resizeWidthChangedSignal((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 3: _t->scrollDiffTextWindow((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 4: _t->newSelection(); break;
        case 5: _t->selectionEnd(); break;
        case 6: _t->setFastSelectorLine((*reinterpret_cast<std::add_pointer_t<LineType>>(_a[1]))); break;
        case 7: _t->gotFocus(); break;
        case 8: _t->lineClicked((*reinterpret_cast<std::add_pointer_t<e_SrcSelector>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LineRef>>(_a[2]))); break;
        case 9: _t->finishRecalcWordWrap((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 10: _t->finishDrop(); break;
        case 11: _t->firstLineChanged((*reinterpret_cast<std::add_pointer_t<LineRef>>(_a[1]))); break;
        case 12: _t->scrollToH((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1]))); break;
        case 13: _t->setFirstLine((*reinterpret_cast<std::add_pointer_t<LineRef>>(_a[1]))); break;
        case 14: _t->setHorizScrollOffset((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 15: _t->resetSelection(); break;
        case 16: _t->setFastSelectorRange((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 17: _t->slotRefresh(); break;
        case 18: _t->slotSelectAll(); break;
        case 19: _t->slotCopy(); break;
        case 20: _t->fwdFinishRecalcWordWrap((*reinterpret_cast<std::add_pointer_t<qint32>>(_a[1]))); break;
        case 21: _t->recalcWordWrapHelper((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<size_t>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(const QString & )>(_a, &DiffTextWindow::statusBarMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(LineType )>(_a, &DiffTextWindow::resizeHeightChangedSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(qint32 )>(_a, &DiffTextWindow::resizeWidthChangedSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(qint32 , qint32 )>(_a, &DiffTextWindow::scrollDiffTextWindow, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)()>(_a, &DiffTextWindow::newSelection, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)()>(_a, &DiffTextWindow::selectionEnd, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(LineType )>(_a, &DiffTextWindow::setFastSelectorLine, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)()>(_a, &DiffTextWindow::gotFocus, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(e_SrcSelector , LineRef )>(_a, &DiffTextWindow::lineClicked, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(qint32 )>(_a, &DiffTextWindow::finishRecalcWordWrap, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)()>(_a, &DiffTextWindow::finishDrop, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(const LineRef )>(_a, &DiffTextWindow::firstLineChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindow::*)(qsizetype )>(_a, &DiffTextWindow::scrollToH, 12))
            return;
    }
}

const QMetaObject *DiffTextWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiffTextWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DiffTextWindowE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int DiffTextWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void DiffTextWindow::statusBarMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DiffTextWindow::resizeHeightChangedSignal(LineType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DiffTextWindow::resizeWidthChangedSignal(qint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DiffTextWindow::scrollDiffTextWindow(qint32 _t1, qint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void DiffTextWindow::newSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DiffTextWindow::selectionEnd()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DiffTextWindow::setFastSelectorLine(LineType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DiffTextWindow::gotFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DiffTextWindow::lineClicked(e_SrcSelector _t1, LineRef _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void DiffTextWindow::finishRecalcWordWrap(qint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DiffTextWindow::finishDrop()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DiffTextWindow::firstLineChanged(const LineRef _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DiffTextWindow::scrollToH(qsizetype _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN19DiffTextWindowFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto DiffTextWindowFrame::qt_create_metaobjectdata<qt_meta_tag_ZN19DiffTextWindowFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiffTextWindowFrame",
        "fileNameChanged",
        "",
        "e_SrcSelector",
        "encodingChanged",
        "setFirstLine",
        "LineRef",
        "firstLine",
        "slotReturnPressed",
        "slotBrowseButtonClicked",
        "slotEncodingChanged",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fileNameChanged'
        QtMocHelpers::SignalData<void(const QString &, e_SrcSelector)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Signal 'encodingChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 },
        }}),
        // Slot 'setFirstLine'
        QtMocHelpers::SlotData<void(LineRef)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'slotReturnPressed'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBrowseButtonClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEncodingChanged'
        QtMocHelpers::SlotData<void(const QByteArray &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DiffTextWindowFrame, qt_meta_tag_ZN19DiffTextWindowFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DiffTextWindowFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DiffTextWindowFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DiffTextWindowFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DiffTextWindowFrameE_t>.metaTypes,
    nullptr
} };

void DiffTextWindowFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiffTextWindowFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<e_SrcSelector>>(_a[2]))); break;
        case 1: _t->encodingChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 2: _t->setFirstLine((*reinterpret_cast<std::add_pointer_t<LineRef>>(_a[1]))); break;
        case 3: _t->slotReturnPressed(); break;
        case 4: _t->slotBrowseButtonClicked(); break;
        case 5: _t->slotEncodingChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindowFrame::*)(const QString & , e_SrcSelector )>(_a, &DiffTextWindowFrame::fileNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiffTextWindowFrame::*)(const QByteArray & )>(_a, &DiffTextWindowFrame::encodingChanged, 1))
            return;
    }
}

const QMetaObject *DiffTextWindowFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiffTextWindowFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DiffTextWindowFrameE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int DiffTextWindowFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DiffTextWindowFrame::fileNameChanged(const QString & _t1, e_SrcSelector _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DiffTextWindowFrame::encodingChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN13EncodingLabelE_t {};
} // unnamed namespace

template <> constexpr inline auto EncodingLabel::qt_create_metaobjectdata<qt_meta_tag_ZN13EncodingLabelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EncodingLabel",
        "encodingChanged",
        "",
        "slotSelectEncoding"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'encodingChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 },
        }}),
        // Slot 'slotSelectEncoding'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EncodingLabel, qt_meta_tag_ZN13EncodingLabelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EncodingLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QLabel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EncodingLabelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EncodingLabelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13EncodingLabelE_t>.metaTypes,
    nullptr
} };

void EncodingLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EncodingLabel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->encodingChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 1: _t->slotSelectEncoding(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EncodingLabel::*)(const QByteArray & )>(_a, &EncodingLabel::encodingChanged, 0))
            return;
    }
}

const QMetaObject *EncodingLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EncodingLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EncodingLabelE_t>.strings))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int EncodingLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void EncodingLabel::encodingChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
