/********************************************************************************
** Form generated from reading UI file 'progressdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROGRESSDIALOG_H
#define UI_PROGRESSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProgressDialog
{
public:
    QVBoxLayout *layout;
    QLabel *information;
    QProgressBar *progressBar;
    QLabel *subInformation;
    QProgressBar *subProgressBar;
    QLabel *slowJobInfo;
    QHBoxLayout *hlayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *abortButton;

    void setupUi(QDialog *ProgressDialog)
    {
        if (ProgressDialog->objectName().isEmpty())
            ProgressDialog->setObjectName("ProgressDialog");
        ProgressDialog->setWindowModality(Qt::ApplicationModal);
        ProgressDialog->resize(634, 261);
        ProgressDialog->setModal(true);
        layout = new QVBoxLayout(ProgressDialog);
        layout->setObjectName("layout");
        layout->setContentsMargins(0, -1, -1, -1);
        information = new QLabel(ProgressDialog);
        information->setObjectName("information");

        layout->addWidget(information);

        progressBar = new QProgressBar(ProgressDialog);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(1000);
        progressBar->setValue(0);

        layout->addWidget(progressBar);

        subInformation = new QLabel(ProgressDialog);
        subInformation->setObjectName("subInformation");

        layout->addWidget(subInformation);

        subProgressBar = new QProgressBar(ProgressDialog);
        subProgressBar->setObjectName("subProgressBar");
        subProgressBar->setMaximum(1000);
        subProgressBar->setValue(0);

        layout->addWidget(subProgressBar);

        slowJobInfo = new QLabel(ProgressDialog);
        slowJobInfo->setObjectName("slowJobInfo");

        layout->addWidget(slowJobInfo);

        hlayout = new QHBoxLayout();
        hlayout->setObjectName("hlayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        hlayout->addItem(horizontalSpacer);

        abortButton = new QPushButton(ProgressDialog);
        abortButton->setObjectName("abortButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(abortButton->sizePolicy().hasHeightForWidth());
        abortButton->setSizePolicy(sizePolicy);

        hlayout->addWidget(abortButton);


        layout->addLayout(hlayout);


        retranslateUi(ProgressDialog);

        QMetaObject::connectSlotsByName(ProgressDialog);
    } // setupUi

    void retranslateUi(QDialog *ProgressDialog)
    {
        ProgressDialog->setWindowTitle(tr2i18n("Dialog", nullptr));
        information->setText(QString());
        subInformation->setText(QString());
        slowJobInfo->setText(QString());
        abortButton->setText(tr2i18n("&Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProgressDialog: public Ui_ProgressDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROGRESSDIALOG_H

